/*********************************************************************
*               SEGGER MICROCONTROLLER GmbH & Co KG                  *
*       Solutions for real time microcontroller applications         *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2009  SEGGER Microcontroller GmbH & Co KG         *
*                                                                    *
*       www.segger.com     Support: support@segger.com               *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: 3.82f                                            *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for MSC ModSDKM16C-CM16C65 development kit
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

/****** Addresses of sfrs and peripheral identifiers ****************/
#define P7  (*(volatile unsigned char*)0x3EDu)   /* Port P7 register */
#define P7D (*(volatile unsigned char*)0x3EFu)   /* Port P7 direction register */

/****** Assign LEDs to Ports ****************************************/
#define LED0_BIT     (0u)
#define LED1_BIT     (3u)
#define LED_MASK_ALL ((1u << LED0_BIT) | (1u << LED1_BIT))

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  //
  // Enable output port for LEDS
  //
  P7D |= LED_MASK_ALL;
  //
  // Initially switch off LEDs
  //
  P7 &= ~LED_MASK_ALL;
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    P7 |= (1u << LED0_BIT);
  } else if (Index == 1) {
    P7 |= (1u << LED1_BIT);
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    P7 &= ~(1u << LED0_BIT);
  } else if (Index == 1) {
    P7 &= ~(1u << LED1_BIT);
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    P7 ^= (1u << LED0_BIT);
  } else if (Index == 1) {
    P7 ^= (1u << LED1_BIT);
  }
}

/****** End Of File *************************************************/
